@@ -991,25 +991,40 @@ def rollback_ui_cmd(stage, traits_input_file, traits_output_file):
     # Move second_last_version  or last_version to previous
     if app["pipeline_metadata"]["deploy"]["second_last_version_folder"] and app["pipeline_metadata"]["deploy"]["second_last_version"]:
         logging.info(f'Syncing second last ui ({app["name"]}) version ({app["pipeline_metadata"]["deploy"]["second_last_version"]}) into (previous)...')
+        s3_cp(
+            f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/versions/{app["pipeline_metadata"]["deploy"]["second_last_version_folder"]}',
+            f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/previous',
+            '--recursive'
+        )
         s3_sync(
             f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/versions/{app["pipeline_metadata"]["deploy"]["second_last_version_folder"]}',
             f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/previous',
-            '--delete --exact-timestamps'
+            '--delete'
         )
     else:
         logging.info(f'No second last version found for ui ({app["name"]})!')
         logging.info(f'Syncing last ui ({app["name"]}) version ({app["pipeline_metadata"]["deploy"]["last_version"]}) into (previous)...')
+        s3_cp(
+            f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/versions/{app["pipeline_metadata"]["deploy"]["last_version_folder"]}',
+            f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/previous',
+            '--recursive'
+        )
         s3_sync(
             f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/versions/{app["pipeline_metadata"]["deploy"]["last_version_folder"]}',
             f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/previous',
-            '--delete --exact-timestamps'
+            '--delete'
         )
 
     logging.info(f'Syncing last ui ({app["name"]}) version ({app["pipeline_metadata"]["deploy"]["last_version"]}) into (live)...')
+    s3_cp(
+        f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/versions/{app["pipeline_metadata"]["deploy"]["last_version_folder"]}',
+        f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/live',
+        f'--exclude "{traits_output_file}" --recursive'
+    )
     s3_sync(
         f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/versions/{app["pipeline_metadata"]["deploy"]["last_version_folder"]}',
         f's3://{app["pipeline_metadata"]["deploy"]["s3_bucket"]}/live',
-        f'--exclude "{traits_output_file}" --delete --exact-timestamps'
+        f'--exclude "{traits_output_file}" --delete'
     )
 
     # Remove deployed version
